\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{coloquio}

%-------------------- This is based on the article class ----------------

\PassOptionsToClass{onecolumn}{article}
\PassOptionsToClass{twoside}{article}
\PassOptionsToClass{letterpaper}{article}

\LoadClass{article}

\RequirePackage{theorem,graphicx,amssymb,amsmath,fancyhdr}

%------------------ Defining the most common environments ---------------

\theorembodyfont{\slshape}

\newtheorem{theorem}{Teorema}
\newtheorem{lemma}[theorem]{Lema}
\newtheorem{cor}[theorem]{Corolario}
\newtheorem{prop}[theorem]{Proposici\'on}
\newtheorem{obs}{Observaci\'on}
\newtheorem{conj}{Conjectura}
\newtheorem{define}{Definici\'on}



\def\QED{\ensuremath{{\square}}}
\def\markatright#1{\leavevmode\unskip\nobreak\quad\hspace*{\fill}{#1}}
\newenvironment{proof}
 {\begin{trivlist}\item[\hskip\labelsep{\bf Demostraci\'on.}]}
 {\markatright{\QED}\end{trivlist}}

%------------------------------------------------------------------------

%
\setlength{\textheight}{643.38pt}
\setlength{\textwidth}{450.52pt}
\setlength{\topmargin}{-27.089pt}
\setlength{\oddsidemargin}{23.754pt}
\setlength{\evensidemargin}{-3.091pt}
\setlength{\headheight}{13.54pt}
\setlength{\headsep}{27.089pt}
\setlength{\footskip}{30.47pt}
\setlength{\parindent}{1em}
\flushbottom


\font\tensfb = cmssbx10
\newcommand{\@titlestyle}{\normalsize\tensfb}

\let\ps@plain\ps@fancy

\renewcommand{\@maketitle}{%
 \newpage
 \null
 \vskip 2em%
 \begin{center}%
   \let \footnote \thanks
   {\vspace{-.2in}\Large\sffamily\bfseries \@title \par}%
   \vskip 1.5em%
   {\normalsize
     \lineskip .5em%
     \begin{tabular}[t]{c}%
       \@author
     \end{tabular}\par}%
   \vskip 1em%
   {\large \@date}%
 \end{center}%
 \par
 \vskip 3em}

\renewenvironment{theindex}
              {\if@twocolumn
                 \@restonecolfalse
               \else
                 \@restonecoltrue
               \fi
               \columnseprule \z@
               \columnsep 35\p@
               \twocolumn[\section*{\indexname}]%
               \@mkboth{\MakeUppercase\indexname}%
                       {\MakeUppercase\indexname}%
               \thispagestyle{fancy}\parindent\z@
               \parskip\z@ \@plus .3\p@\relax
               \let\item\@idxitem}
              {\if@restonecol\onecolumn\else\clearpage\fi}
              
              
 \renewcommand\refname{Referencias}   
 
 \renewcommand{\figurename}{Figura}

\renewcommand\section{\@startsection {section}{1}{\z@}{-3.5ex plus
   -1ex minus -.2ex}{2.3ex plus .2ex}{\@titlestyle}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}{-3.25ex
   plus -1ex minus -.2ex}{1.5ex plus .2ex}{\@titlestyle}}
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}{-3.25ex
   plus -1ex minus -.2ex}{1.5ex plus .2ex}{\@titlestyle}}
\renewcommand\paragraph{\@startsection {paragraph}{4}{\z@}{3.25ex plus
   1ex minus .2ex}{-1em}{\@titlestyle}}
\renewcommand\subparagraph{\@startsection
 {subparagraph}{4}{\parindent}{3.25ex plus 1ex minus
   .2ex}{-1em}{\@titlestyle}}

\renewcommand\abstract{\if@twocolumn
\section*{Resumen}
\else \small
\begin{center}
{\sffamily\bfseries Resumen\vspace{-.5em}\vspace{0pt}}
\end{center}
\quotation
\fi}


\def\endabstract{\if@twocolumn\else\endquotation\fi}

\date{}

\renewcommand{\textfraction}{0.05}
\renewcommand{\bottomfraction}{0.95}
\renewcommand{\topfraction}{0.95}
\renewcommand{\dbltopfraction}{0.95}
\renewcommand{\dblfloatpagefraction}{0.8}
\setcounter{topnumber}{3}

\newcommand{\l@day}{\@dottedtocline{1}{0em}{0em}}
\newcommand{\l@session}{\@dottedtocline{1}{0em}{1in}}
\newcommand{\l@algorithm}{\@dottedtocline{1}{0em}{1in}}
\renewcommand{\@dotsep}{500}

%--------------------------- Headers and Footers ------------------------

\fancypagestyle{plain}{
\fancyhead[RO]{\sf XXX Coloquio V\'ictor Neumann-Lara de Teor\'ia de Gr\'aficas, Combinatoria y sus Aplicaciones}
\fancyhead[LE]{\sf Oaxaca, M\'exico, 2 - 6 de marzo de 2015}}


\pagestyle{fancy}
\fancyhead{}
\fancyfoot{}
\fancyhead[RO]{\sf XXX Coloquio V\'ictor Neumann-Lara de Teor\'ia de Gr\'aficas, Combinatoria y sus Aplicaciones}
\fancyhead[LE]{\sf Oaxaca, M\'exico, 2 - 6 de marzo de 2015}


\renewcommand{\headrulewidth}{1pt}

\endinput
